==> camel-core-2.7.0-sources.jar: org/apache/camel/builder/xml/TimeUnitAdapter.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.builder.xml;

import java.util.concurrent.TimeUnit;

import javax.xml.bind.annotation.adapters.XmlAdapter;

/**
 * <code>TimeUnitAdapter</code> is a simple adapter to convert between Strings
 * and instances of the {@link TimeUnit} enumeration
 */
public class TimeUnitAdapter extends XmlAdapter<String, TimeUnit> {

    @Override
    public String marshal(TimeUnit v) throws Exception {
        String result = null;
        if (v != null) {
            result = v.toString();
        }
        return result;
    }

    @Override
    public TimeUnit unmarshal(String v) throws Exception {
        TimeUnit result = null;
        if (v != null) {
            result = TimeUnit.valueOf(v.toUpperCase());
        }
        return result;
    }

}

==> camel-core-2.15-20150307.023702-161-sources.jar: org/apache/camel/builder/xml/TimeUnitAdapter.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.builder.xml;

import java.util.Locale;
import java.util.concurrent.TimeUnit;

import javax.xml.bind.annotation.adapters.XmlAdapter;

/**
 * <code>TimeUnitAdapter</code> is a simple adapter to convert between Strings
 * and instances of the {@link TimeUnit} enumeration
 */
public class TimeUnitAdapter extends XmlAdapter<String, TimeUnit> {

    @Override
    public String marshal(TimeUnit v) throws Exception {
        String result = null;
        if (v != null) {
            result = v.toString();
        }
        return result;
    }

    @Override
    public TimeUnit unmarshal(String v) throws Exception {
        TimeUnit result = null;
        if (v != null) {
            result = TimeUnit.valueOf(v.toUpperCase(Locale.ENGLISH));
        }
        return result;
    }

}
